@@ -28,7 +28,6 @@ NULL
 .get_esalandcover <- function(x,
                               rundir = tempdir(),
                               verbose = TRUE) {
-  bbox <- st_bbox(x)
   target_years <- attributes(x)$years
   available_years <- c(2015:2019)
   target_years <- .check_available_years(
@@ -40,7 +39,7 @@ NULL
     xmin = -180, xmax = 180, dx = 20,
     ymin = -60, ymax = 80, dy = 20
   )
-  tile_ids <- st_intersects(st_as_sfc(bbox), grid_esa)[[1]]
+  tile_ids <- unlist(st_intersects(x, grid_esa))
   if (length(tile_ids) == 0) {
     stop(paste("The extent of the portfolio does not ",
       "intersect with the Land Cover grid.",
