@@ -24,6 +24,9 @@ get_resources <- function(x, resources, ...) {
   if (!connection_available) {
     stop("There seems to be no internet connection. Cannot download resources.")
   }
+
+  # depreciation warining for old resource names
+  resources <- .depreciation_warning(resources, resource = TRUE)
   # check if the requested resource is supported
   .check_requested_resources(resources)
   # check if any of the requested resources is already locally available
@@ -32,6 +35,7 @@ get_resources <- function(x, resources, ...) {
   if (length(resources) == 0) {
     return(x)
   }
+
   # get the resources
   ## TODO: check if we can go parallel here. Problem is when errors occur
   # for one resource and it terminates the complete process. We would have
