@@ -27,7 +27,7 @@
     unsupported <- indicators[which(!indicators %in% names_indicators)]
     base_msg <- "The following requested %s not supported: %s."
     mid_msg <- ifelse(length(unsupported) == 1,
-      "indicator is", "indicators are"
+                      "indicator is", "indicators are"
     )
     end_msg <- paste(unsupported, collapse = ", ")
     stop(sprintf(base_msg, mid_msg, end_msg))
@@ -68,8 +68,8 @@
       nonexisting <- req_resources[which(!req_resources %in% ex_resources)]
       base_msg <- "The following required %s not available: %s."
       mid_msg <- ifelse(length(nonexisting) == 1,
-        "resource is",
-        "resources are"
+                        "resource is",
+                        "resources are"
       )
       end_msg <- paste(nonexisting, collapse = ", ")
       stop(sprintf(base_msg, mid_msg, end_msg))
@@ -105,8 +105,8 @@
     unspecified_args <- req_args_names[!req_args_names %in% names(args)]
   }
   base_msg <- paste("Argument '%s' for resource '%s' was not specified. ",
-    "Setting to default value of '%s'.",
-    sep = ""
+                    "Setting to default value of '%s'.",
+                    sep = ""
   )
   default_args <- as.list(sapply(unspecified_args, function(arg_name) {
     message(
@@ -200,7 +200,7 @@
   if (any(!target_years %in% available_years)) {
     target_years <- target_years[target_years %in% available_years]
     if(length(target_years) > 0 ){
-    message(sprintf("Some target years are not available for %s.", indicator))
+      message(sprintf("Some target years are not available for %s.", indicator))
     } else {
       stop(
         sprintf(
@@ -224,8 +224,8 @@
   if (!queried_engine %in% implemented_engines) {
     stop(sprintf(
       paste("Engine '%s' is not an available engine.",
-        "Please choose one of: %s",
-        collapse = " "
+            "Please choose one of: %s",
+            collapse = " "
       ),
       queried_engine, paste(implemented_engines, collapse = ", ")
     ))
@@ -301,8 +301,8 @@
         }
 
         status <- download.file(missing_urls[i], missing_filenames[i],
-          quiet = TRUE, "libcurl",
-          mode = ifelse(Sys.info()["sysname"] == "Windows", "wb", "w")
+                                quiet = TRUE, "libcurl",
+                                mode = ifelse(Sys.info()["sysname"] == "Windows", "wb", "w")
         )
         if (status != 0) {
           return(list(urls = missing_urls[i], filenames = missing_filenames[i]))
@@ -314,8 +314,8 @@
       unsuccessful <- unsuccessful[which(sapply(unsuccessful, function(x) !is.null(x)))]
       if (length(unsuccessful) > 0 & counter <= stubbornnes) {
         warning(paste("Some target files have not been downloaded correctly. ",
-          "Download will be retried.",
-          sep = ""
+                      "Download will be retried.",
+                      sep = ""
         ))
         missing_urls <- sapply(unsuccessful, function(x) x$missing_urls)
         missing_filenames <- sapply(unsuccessful, function(x) x$missing_filenames)
@@ -348,3 +348,86 @@
   }
   return(filenames)
 }
+
+
+.depreciation_warning <- function(names, resource){
+  resources <- tibble(
+    old = c("treecover2000",
+            "lossyear",
+            "greenhouse",
+            "traveltime",
+            "nasagrace",
+            "mintemperature",
+            "maxtemperature",
+            "precipitation",
+            "ecoregions",
+            "mangrove",
+            "srtmdem"),
+    new = c("gfw_treecover",
+            "gfw_lossyear",
+            "gfw_emissions",
+            "nelson_et_al",
+            "nasa_grace",
+            "worldclim_min_temperature",
+            "worldclim_max_temperature",
+            "worldclim_precipitation",
+            "teow",
+            "gmw",
+            "nasa_srtm")
+  )
+
+  indicators <- tibble(
+    old = c("treecover",
+            "emissions",
+            "treeloss",
+            "chirpsprec",
+            "accessibility",
+            "popcount",
+            "wctmin",
+            "wctmax",
+            "wcprec",
+            "gmw",
+            "teow"
+    ),
+    new = c("treecover_area",
+            "treecoverloss_emissions",
+            "treecover_area_and_emissions",
+            "precipitation_chirps",
+            "traveltime",
+            "population_count",
+            "temperature_min_wc",
+            "temperature_max_wc",
+            "precipitation_wc",
+            "mangroves_area",
+            "ecoregion")
+  )
+
+  if(resource){
+    basemsg <- paste("Resource '%s' has been renamed to '%s'. In the next release '%s'",
+                     "will no longer be supported.\nPlease adjust your scripts accordingly.", sep = " ")
+    for (name in names){
+      if(name %in% resources$old){
+        old <- name
+        new <- resources$new[which(resources$old == name)]
+        msg <- sprintf(basemsg, old, new, old)
+        warning(msg)
+        names[names == name] <- new
+      }
+    }
+  }
+
+  if(!resource){
+    basemsg <- paste("Indicator '%s' has been renamed to '%s'. In the next release '%s'",
+                     "will no longer be supported.\nPlease adjust your scripts accordingly.", sep = " ")
+    for (name in names){
+      if(name %in% indicators$old){
+        old <- name
+        new <- indicators$new[which(indicators$old == name)]
+        msg <- sprintf(basemsg, old, new, old)
+        warning(msg)
+        names[names == name] <- new
+      }
+    }
+  }
+  names
+}
