@@ -1,38 +1,38 @@
 test_that(".check_requested_resources works", {
-  expect_equal(.check_requested_resources("treecover2000"), NULL)
+  expect_equal(.check_requested_resources("gfw_treecover"), NULL)
   expect_error(.check_requested_resources("notavailable"))
-  expect_error(.check_requested_resources(c("treecover2000", "notavailable")), "resource is")
-  expect_error(.check_requested_resources(c("treecover2000", "notavailable1", "notavailable2")), "resources are")
+  expect_error(.check_requested_resources(c("gfw_treecover", "notavailable")), "resource is")
+  expect_error(.check_requested_resources(c("gfw_treecover", "notavailable1", "notavailable2")), "resources are")
 })
 
 
 test_that(".check_requested_indicator works", {
-  expect_equal(.check_requested_indicator("treecover"), c("treecover2000", "lossyear"))
-  expect_equal(.check_requested_indicator(c("treecover", "emissions")), c("treecover2000", "lossyear", "greenhouse"))
+  expect_equal(.check_requested_indicator("treecover_area"), c("gfw_treecover", "gfw_lossyear"))
+  expect_equal(.check_requested_indicator(c("treecover_area", "treecoverloss_emissions")), c("gfw_treecover", "gfw_lossyear", "gfw_emissions"))
   expect_error(.check_requested_indicator("notavailable"))
-  expect_error(.check_requested_indicator(c("treecover", "notavailable")), "indicator is")
-  expect_error(.check_requested_indicator(c("treecover", "notavailable1", "notavailable2")), "indicators are")
+  expect_error(.check_requested_indicator(c("treecover_area", "notavailable")), "indicator is")
+  expect_error(.check_requested_indicator(c("treecover_area", "notavailable1", "notavailable2")), "indicators are")
 })
 
 
 test_that(".check_existing_resources works", {
-  available_resource <- c("treecover2000", "lossyear")
-  expect_message(.check_existing_resources(available_resource, "treecover2000"), "is already available")
-  expect_message(.check_existing_resources(available_resource, c("treecover2000", "lossyear")), "are already available")
-  expect_equal(.check_existing_resources(available_resource, "treecover2000", needed = T), NULL)
-  expect_equal(.check_existing_resources(available_resource, c("treecover2000", "lossyear"), needed = T), NULL)
+  available_resource <- c("gfw_treecover", "gfw_lossyear")
+  expect_message(.check_existing_resources(available_resource, "gfw_treecover"), "is already available")
+  expect_message(.check_existing_resources(available_resource, c("gfw_treecover", "gfw_lossyear")), "are already available")
+  expect_equal(.check_existing_resources(available_resource, "gfw_treecover", needed = T), NULL)
+  expect_equal(.check_existing_resources(available_resource, c("gfw_treecover", "gfw_lossyear"), needed = T), NULL)
   expect_equal(.check_existing_resources(available_resource, "srtmelevation"), "srtmelevation")
   expect_error(.check_existing_resources(available_resource, "srtmelevation", needed = TRUE), "required resource is not available")
   expect_equal(.check_existing_resources(available_resource, c("srtmelevation", "accessibility")), c("srtmelevation", "accessibility"))
   expect_error(.check_existing_resources(available_resource, c("srtmelevation", "accessibility"), needed = TRUE), "required resources are not available")
-  expect_message(out <- .check_existing_resources(available_resource, c("treecover2000", "srtmelevation", "accessibility")), "requested resource is already available")
+  expect_message(out <- .check_existing_resources(available_resource, c("gfw_treecover", "srtmelevation", "accessibility")), "requested resource is already available")
   expect_equal(out, c("srtmelevation", "accessibility"))
-  expect_error(.check_existing_resources(available_resource, c("treecover2000", "srtmelevation", "accessibility"), needed = TRUE), "required resources are not available")
+  expect_error(.check_existing_resources(available_resource, c("gfw_treecover", "srtmelevation", "accessibility"), needed = TRUE), "required resources are not available")
 })
 
 test_that(".check_resource_arguments works", {
-  resource <- available_resources("treecover2000")
-  expect_message(out <- .check_resource_arguments(resource, args = list()), "Argument 'vers_treecover' for resource 'treecover2000' was not specified")
+  resource <- available_resources("gfw_treecover")
+  expect_message(out <- .check_resource_arguments(resource, args = list()), "Argument 'vers_treecover' for resource 'gfw_treecover' was not specified")
   expect_equal(out, list(vers_treecover = "GFC-2020-v1.8"))
   expect_equal(.check_resource_arguments(resource, args = list(vers_treecover = "GFC-2020-v1.8")), list(vers_treecover = "GFC-2020-v1.8"))
   expect_equal(.check_resource_arguments(resource, args = list(vers_treecover = "GFC-2020-v1.8", noarg = NA)), list(vers_treecover = "GFC-2020-v1.8"))
@@ -57,19 +57,19 @@ test_that(".get_gfw_tile_id works", {
 
 test_that(".check_available_years works", {
   expect_equal(
-    .check_available_years(2000:2020, 2000:2020, indicator = "treecover"),
+    .check_available_years(2000:2020, 2000:2020, indicator = "treecover_area"),
     2000:2020
   )
   expect_equal(
-    .check_available_years(2000:2010, 2000:2020, indicator = "treecover"),
+    .check_available_years(2000:2010, 2000:2020, indicator = "treecover_area"),
     2000:2010
   )
   expect_error(
-    .check_available_years(2000:2010, 2011:2020, indicator = "treecover"),
+    .check_available_years(2000:2010, 2011:2020, indicator = "treecover_area"),
     "The target years do not intersect with the availability of treecover."
   )
   expect_message(
-    out <- .check_available_years(2000:2011, 2011:2020, indicator = "treecover"),
+    out <- .check_available_years(2000:2011, 2011:2020, indicator = "treecover_area"),
     "Some target years are not available for treecover."
   )
   expect_equal(out, 2011)
